@@ -466,7 +466,7 @@ static inline void prepare_context (gst_context_part context,
 
 /* Return from the current context and restore the virtual machine's
    status (ip, sp, _gst_this_method, _gst_self, ...).  */
-static void unwind_context (void);
+static void __attribute__ ((__always_inline__)) unwind_context (void);
 
 /* Check whether it is true that sending SENDSELECTOR to RECEIVER
    accepts NUMARGS arguments.  Note that the RECEIVER is only used to
@@ -780,8 +780,6 @@ empty_context_stack (void)
 void
 alloc_new_chunk (void)
 {
-  gst_method_context newContext;
-
   if UNCOMMON (++chunk >= &chunks[MAX_CHUNKS_IN_MEMORY])
     {
       /* No more chunks available - GC */
@@ -791,20 +789,13 @@ alloc_new_chunk (void)
 
   empty_context_stack ();
 
-  newContext = (gst_method_context) * chunk;
-  if UNCOMMON (!newContext)
-    {
-      /* Allocate memory only the first time we're using the chunk.
-         _gst_empty_context_pool resets the status but doesn't free
-         the memory.  */
-      cur_chunk_begin = *chunk = (gst_context_part)
-        xcalloc (1, SIZE_TO_BYTES (CHUNK_SIZE));
-
-      newContext = (gst_method_context) cur_chunk_begin;
-    }
-  else
-    cur_chunk_begin = *chunk;
+  /* Allocate memory only the first time we're using the chunk.
+     _gst_empty_context_pool resets the status but doesn't free
+     the memory.  */
+  if UNCOMMON (!*chunk)
+    *chunk = (gst_context_part) xcalloc (1, SIZE_TO_BYTES (CHUNK_SIZE));
 
+  cur_chunk_begin = *chunk;
   cur_chunk_end = (gst_context_part) (
     ((char *) cur_chunk_begin) + SIZE_TO_BYTES(CHUNK_SIZE));
 }
@@ -1033,14 +1024,13 @@ void
 unwind_context (void)
 {
   gst_method_context oldContext, newContext;
-  OOP oldContextOOP, newContextOOP;
+  OOP newContextOOP;
 
   newContextOOP = _gst_this_context_oop;
   newContext = (gst_method_context) OOP_TO_OBJ (newContextOOP);
 
   do
     {
-      oldContextOOP = newContextOOP;
       oldContext = newContext;
 
       /* Descend in the chain...  */
@@ -1203,7 +1193,7 @@ unwind_to (OOP returnContextOOP)
 mst_Boolean
 disable_non_unwind_contexts (OOP returnContextOOP)
 {
-  OOP oldContextOOP, newContextOOP, *chain;
+  OOP newContextOOP, *chain;
   gst_method_context oldContext, newContext;
 
   newContextOOP = _gst_this_context_oop;
@@ -1212,7 +1202,6 @@ disable_non_unwind_contexts (OOP returnContextOOP)
 
   for (;;)
     {
-      oldContextOOP = newContextOOP;
       oldContext = newContext;
 
       /* Descend in the chain...  */
@@ -1250,7 +1239,6 @@ disable_non_unwind_contexts (OOP returnContextOOP)
   while UNCOMMON (CONTEXT_FLAGS (newContext)
                   == (MCF_IS_METHOD_CONTEXT | MCF_IS_DISABLED_CONTEXT))
     {
-      oldContextOOP = newContextOOP;
       oldContext = newContext;
 
       /* Descend in the chain...  */
@@ -2104,22 +2092,24 @@ create_callin_process (OOP contextOOP)
   OOP processListsOOP;
   gst_processor_scheduler processor;
   gst_process initialProcess;
-  OOP initialProcessOOP, initialProcessListOOP;
+  OOP initialProcessOOP, initialProcessListOOP, nameOOP;
   inc_ptr inc = INC_SAVE_POINTER ();
 
   processor = (gst_processor_scheduler) OOP_TO_OBJ (_gst_processor_oop);
   processListsOOP = processor->processLists;
   initialProcessListOOP = ARRAY_AT (processListsOOP, 4);
 
+  nameOOP = _gst_string_new ("call-in process");
+  INC_ADD_OOP (nameOOP);
+
   initialProcess = (gst_process)
     instantiate (_gst_callin_process_class, &initialProcessOOP);
 
   INC_ADD_OOP (initialProcessOOP);
-
   initialProcess->priority = FROM_INT (USER_SCHEDULING_PRIORITY);
   initialProcess->interruptLock = _gst_nil_oop;
   initialProcess->suspendedContext = contextOOP;
-  initialProcess->name = _gst_string_new ("call-in process");
+  initialProcess->name = nameOOP;
   INC_RESTORE_POINTER (inc);
 
   /* Put initialProcessOOP in the root set */
